vfbLib.parsers.pclt.PcltParser
==============================

.. currentmodule:: vfbLib.parsers.pclt

.. autoclass:: PcltParser
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~PcltParser.__init__
      ~PcltParser.parse
      ~PcltParser.parse_hex
      ~PcltParser.read_double
      ~PcltParser.read_doubles
      ~PcltParser.read_float
      ~PcltParser.read_floats
      ~PcltParser.read_int16
      ~PcltParser.read_int32
      ~PcltParser.read_int8
      ~PcltParser.read_str
      ~PcltParser.read_str_all
      ~PcltParser.read_uint16
      ~PcltParser.read_uint32
      ~PcltParser.read_uint8
      ~PcltParser.read_value
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~PcltParser.encoding
      ~PcltParser.master_count
      ~PcltParser.stream
      ~PcltParser.ttStemsH_count
      ~PcltParser.ttStemsV_count
   
   